==> haskell-tls-session-manager-0.0.1.0-6-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.1.0
id: tls-session-manager-0.0.1.0-WKlICNTWAHGUzIJcp0CVU
key: tls-session-manager-0.0.1.0-WKlICNTWAHGUzIJcp0CVU
license: BSD-3-Clause
maintainer: kazu@iij.ad.jp
author: Kazu Yamamoto
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
abi: 0df57a6f58c3883613ec9a98625b7930
exposed: True
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
import-dirs: /usr/lib/ghc-8.6.5/site-local/tls-session-manager-0.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/tls-session-manager-0.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tls-session-manager-0.0.1.0
hs-libraries: HStls-session-manager-0.0.1.0-WKlICNTWAHGUzIJcp0CVU
depends:
    auto-update-0.1.5-5mFkKoJe6uJDtwkKyg6SyM base-4.12.0.0
    clock-0.8-H1S1zDefxirImaRbI6ITNv
    psqueues-0.2.7.2-9sugYpzJ4dhJIjiVo1W3k9
    tls-1.4.1-9djT5VIuTo39J8pPsZghHq
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tls-session-manager-0.0.1.0-7-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-tls-session-manager.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tls-session-manager
version: 0.0.1.0
id: tls-session-manager-0.0.1.0-6Yj4qDz0aUduSPz9tJiWk
key: tls-session-manager-0.0.1.0-6Yj4qDz0aUduSPz9tJiWk
license: BSD-3-Clause
maintainer: kazu@iij.ad.jp
author: Kazu Yamamoto
synopsis: In-memory TLS session manager
description:
    TLS session manager with limitation, automatic pruning, energy saving and replay resistance
category: Web
abi: 91b5e918457a91402f2ea2f5154cde2c
exposed: True
exposed-modules:
    Network.TLS.SessionManager
hidden-modules: Network.TLS.Imports
import-dirs: /usr/lib/ghc-8.6.5/site-local/tls-session-manager-0.0.1.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/tls-session-manager-0.0.1.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/tls-session-manager-0.0.1.0
hs-libraries: HStls-session-manager-0.0.1.0-6Yj4qDz0aUduSPz9tJiWk
depends:
    auto-update-0.1.6-5YODUUJhCSMEJkYrfTvb4B base-4.12.0.0
    clock-0.8-H1S1zDefxirImaRbI6ITNv
    psqueues-0.2.7.2-9sugYpzJ4dhJIjiVo1W3k9
    tls-1.4.1-9djT5VIuTo39J8pPsZghHq
haddock-interfaces: /usr/share/doc/haskell-tls-session-manager/html/tls-session-manager.haddock
haddock-html: /usr/share/doc/haskell-tls-session-manager/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
